==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/EntityRiskPolicyRuleActionRunWorkflow.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.EntityRiskPolicyRuleActionRunWorkflowWorkflow;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * EntityRiskPolicyRuleActionRunWorkflow
 */
@JsonPropertyOrder({ EntityRiskPolicyRuleActionRunWorkflow.JSON_PROPERTY_ACTION,
        EntityRiskPolicyRuleActionRunWorkflow.JSON_PROPERTY_WORKFLOW })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class EntityRiskPolicyRuleActionRunWorkflow implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * Gets or Sets action
     */
    public enum ActionEnum {
        RUN_WORKFLOW("RUN_WORKFLOW"),

        UNKNOWN_DEFAULT_OPEN_API("unknown_default_open_api");

        private String value;

        ActionEnum(String value) {
            this.value = value;
        }

        @JsonValue
        public String getValue() {
            return value;
        }

        @Override
        public String toString() {
            return String.valueOf(value);
        }

        @JsonCreator
        public static ActionEnum fromValue(String value) {
            for (ActionEnum b : ActionEnum.values()) {
                if (b.value.equals(value)) {
                    return b;
                }
            }
            return UNKNOWN_DEFAULT_OPEN_API;
        }
    }

    public static final String JSON_PROPERTY_ACTION = "action";
    private ActionEnum action;

    public static final String JSON_PROPERTY_WORKFLOW = "workflow";
    private EntityRiskPolicyRuleActionRunWorkflowWorkflow workflow;

    public EntityRiskPolicyRuleActionRunWorkflow() {
    }

    public EntityRiskPolicyRuleActionRunWorkflow action(ActionEnum action) {

        this.action = action;
        return this;
    }

    /**
     * Get action
     *
     * @return action
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ACTION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public ActionEnum getAction() {
        return action;
    }

    @JsonProperty(JSON_PROPERTY_ACTION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAction(ActionEnum action) {
        this.action = action;
    }

    public EntityRiskPolicyRuleActionRunWorkflow workflow(EntityRiskPolicyRuleActionRunWorkflowWorkflow workflow) {

        this.workflow = workflow;
        return this;
    }

    /**
     * Get workflow
     *
     * @return workflow
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_WORKFLOW)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public EntityRiskPolicyRuleActionRunWorkflowWorkflow getWorkflow() {
        return workflow;
    }

    @JsonProperty(JSON_PROPERTY_WORKFLOW)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setWorkflow(EntityRiskPolicyRuleActionRunWorkflowWorkflow workflow) {
        this.workflow = workflow;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        EntityRiskPolicyRuleActionRunWorkflow entityRiskPolicyRuleActionRunWorkflow = (EntityRiskPolicyRuleActionRunWorkflow) o;
        return Objects.equals(this.action, entityRiskPolicyRuleActionRunWorkflow.action)
                && Objects.equals(this.workflow, entityRiskPolicyRuleActionRunWorkflow.workflow);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(action, workflow);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class EntityRiskPolicyRuleActionRunWorkflow {\n");
        sb.append("    action: ").append(toIndentedString(action)).append("\n");
        sb.append("    workflow: ").append(toIndentedString(workflow)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-24.0.0-sources.jar: com/okta/sdk/resource/model/EntityRiskPolicyRuleActionRunWorkflow.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.EntityRiskPolicyRuleActionRunWorkflowWorkflow;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * EntityRiskPolicyRuleActionRunWorkflow
 */
@JsonPropertyOrder({ EntityRiskPolicyRuleActionRunWorkflow.JSON_PROPERTY_ACTION,
        EntityRiskPolicyRuleActionRunWorkflow.JSON_PROPERTY_WORKFLOW })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-07-28T10:14:57.946459+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class EntityRiskPolicyRuleActionRunWorkflow implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * Gets or Sets action
     */
    public enum ActionEnum {
        RUN_WORKFLOW(String.valueOf("RUN_WORKFLOW")),

        UNKNOWN_DEFAULT_OPEN_API(String.valueOf("unknown_default_open_api"));

        private String value;

        ActionEnum(String value) {
            this.value = value;
        }

        @JsonValue
        public String getValue() {
            return value;
        }

        @Override
        public String toString() {
            return String.valueOf(value);
        }

        @JsonCreator
        public static ActionEnum fromValue(String value) {
            for (ActionEnum b : ActionEnum.values()) {
                if (b.value.equals(value)) {
                    return b;
                }
            }
            return UNKNOWN_DEFAULT_OPEN_API;
        }
    }

    public static final String JSON_PROPERTY_ACTION = "action";
    private ActionEnum action;

    public static final String JSON_PROPERTY_WORKFLOW = "workflow";
    private EntityRiskPolicyRuleActionRunWorkflowWorkflow workflow;

    public EntityRiskPolicyRuleActionRunWorkflow() {
    }

    public EntityRiskPolicyRuleActionRunWorkflow action(ActionEnum action) {

        this.action = action;
        return this;
    }

    /**
     * Get action
     *
     * @return action
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ACTION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public ActionEnum getAction() {
        return action;
    }

    @JsonProperty(JSON_PROPERTY_ACTION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAction(ActionEnum action) {
        this.action = action;
    }

    public EntityRiskPolicyRuleActionRunWorkflow workflow(EntityRiskPolicyRuleActionRunWorkflowWorkflow workflow) {

        this.workflow = workflow;
        return this;
    }

    /**
     * Get workflow
     *
     * @return workflow
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_WORKFLOW)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public EntityRiskPolicyRuleActionRunWorkflowWorkflow getWorkflow() {
        return workflow;
    }

    @JsonProperty(JSON_PROPERTY_WORKFLOW)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setWorkflow(EntityRiskPolicyRuleActionRunWorkflowWorkflow workflow) {
        this.workflow = workflow;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        EntityRiskPolicyRuleActionRunWorkflow entityRiskPolicyRuleActionRunWorkflow = (EntityRiskPolicyRuleActionRunWorkflow) o;
        return Objects.equals(this.action, entityRiskPolicyRuleActionRunWorkflow.action)
                && Objects.equals(this.workflow, entityRiskPolicyRuleActionRunWorkflow.workflow);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(action, workflow);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class EntityRiskPolicyRuleActionRunWorkflow {\n");
        sb.append("    action: ").append(toIndentedString(action)).append("\n");
        sb.append("    workflow: ").append(toIndentedString(workflow)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
